@@ -57,3 +57,5 @@ status_elapsed_error = "request elapsed error"
 status_requests_method_error = "requests method error"
 status_requests_url_error = "requests url error"
 status_requests_body_error = "requests body error"
+# HTML
+html_generate_no_data_tag = "record is None"
